pub struct WrapperMethods;Expand description
Wrapper-based feature selection methods
Implementations
Sourceimpl WrapperMethods
impl WrapperMethods
Sourcepub fn forward_selection(
features: &Array2<f64>,
target: &Array1<f64>,
config: &FeatureSelectionConfig,
) -> Result<FeatureSelectionResult>
pub fn forward_selection( features: &Array2<f64>, target: &Array1<f64>, config: &FeatureSelectionConfig, ) -> Result<FeatureSelectionResult>
Forward feature selection
Starts with no features and iteratively adds the best feature.
Arguments
features- Feature matrix (samples x features)target- Target variableconfig- Configuration for selection
Returns
- Feature selection result
Example
use scirs2_core::ndarray::{Array1, Array2};
use scirs2_series::feature_selection::{WrapperMethods, FeatureSelectionConfig};
let features = Array2::from_shape_vec((100, 10), (0..1000).map(|x| x as f64).collect()).expect("Operation failed");
let target = Array1::from_vec((0..100).map(|x| x as f64).collect());
let config = FeatureSelectionConfig::default();
let result = WrapperMethods::forward_selection(&features, &target, &config).expect("Operation failed");
println!("Selected {} features", result.selected_features.len());Sourcepub fn backward_elimination(
features: &Array2<f64>,
target: &Array1<f64>,
config: &FeatureSelectionConfig,
) -> Result<FeatureSelectionResult>
pub fn backward_elimination( features: &Array2<f64>, target: &Array1<f64>, config: &FeatureSelectionConfig, ) -> Result<FeatureSelectionResult>
Sourcepub fn recursive_feature_elimination(
features: &Array2<f64>,
target: &Array1<f64>,
config: &FeatureSelectionConfig,
) -> Result<FeatureSelectionResult>
pub fn recursive_feature_elimination( features: &Array2<f64>, target: &Array1<f64>, config: &FeatureSelectionConfig, ) -> Result<FeatureSelectionResult>
Sourcepub fn bidirectional_selection(
features: &Array2<f64>,
target: &Array1<f64>,
config: &FeatureSelectionConfig,
) -> Result<FeatureSelectionResult>
pub fn bidirectional_selection( features: &Array2<f64>, target: &Array1<f64>, config: &FeatureSelectionConfig, ) -> Result<FeatureSelectionResult>
Sourcepub fn evaluate_feature_subset(
features: &Array2<f64>,
target: &Array1<f64>,
feature_indices: &[usize],
config: &FeatureSelectionConfig,
) -> Result<f64>
pub fn evaluate_feature_subset( features: &Array2<f64>, target: &Array1<f64>, feature_indices: &[usize], config: &FeatureSelectionConfig, ) -> Result<f64>
Evaluate the performance of a feature subset using the configured scoring method
Sourcepub fn fit_predict_linear(
features: &Array2<f64>,
target: &Array1<f64>,
) -> Result<Array1<f64>>
pub fn fit_predict_linear( features: &Array2<f64>, target: &Array1<f64>, ) -> Result<Array1<f64>>
Fit a linear regression model and return predictions